package com.miya.fastcashier.ui

import android.content.Intent
import android.os.Bundle
import android.text.TextUtils
import android.view.View
import android.widget.Toast
import androidx.lifecycle.ViewModelProvider
import com.alibaba.fastjson.JSON
import com.miya.fastcashier.databinding.ActivityPriceInputBinding
import com.miya.fastcashier.utils.CenterToasty
import com.miya.fastcashier.viewmodel.PayViewModel
import com.miya.fastcashier.widget.NumKeyboard.DELETE
import com.miya.fastcashier.widget.NumKeyboard.DOT
import java.math.BigDecimal


class PriceInputActivity : BaseActivity() {
    private lateinit var viewModel: PayViewModel
    private lateinit var binding: ActivityPriceInputBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        binding = ActivityPriceInputBinding.inflate(layoutInflater)
        setContentView(binding.root)
        viewModel = ViewModelProvider(this).get(PayViewModel::class.java)

        val tvGeneratePayCode = binding.tvGeneratePayCode
        val tvScanPayCode = binding.tvScanPayCode
        val tvBack = binding.tvBack
        val ivBack = binding.ivBack
        val etPrice = binding.etPrice
        val loading = binding.loading
        val numKeyboard = binding.numKeyboard

        tvScanPayCode.setOnClickListener{
            CenterToasty.normal(this,"暂时不支持此功能", Toast.LENGTH_SHORT).show();
        }

        tvGeneratePayCode.setOnClickListener{
            loading.visibility = View.VISIBLE
            viewModel.generatePayCode(etPrice.text.toString(),"1")
        }

        tvBack.setOnClickListener{ finish() }
        ivBack.setOnClickListener{ finish() }

        numKeyboard.setKeyboardClickListener {
            when (it) {
                DELETE -> {
                    if (TextUtils.isEmpty(etPrice.text.toString())) {
                        return@setKeyboardClickListener
                    }
                    var currentCode: String = etPrice.text.toString()
                    currentCode = if (currentCode.length <= 1) {
                        ""
                    } else {
                        currentCode.substring(0, currentCode.length - 1)
                    }
                    etPrice.setText(currentCode)
                }
                DOT -> {
                    var currentCode: String = etPrice.text.toString()
                    if (!currentCode.contains(".") && !TextUtils.isEmpty(currentCode)) {
                        currentCode += "."
                        etPrice.setText(currentCode)
                    } else {
                        CenterToasty.error(this,"金额格式有误！",Toast.LENGTH_LONG).show()
                    }
                }
                else -> {
                    var currentCode: String = etPrice.text.toString()
                    if (currentCode.contains(".")) {
                        val tmp = currentCode.substring(currentCode.indexOf("."), currentCode.length - 1)
                        if (tmp.length < 2) {
                            if (BigDecimal(currentCode + it).compareTo(BigDecimal.ZERO) == 0 && tmp.length == 1) {
                                CenterToasty.error(this,"金额不能为0！",Toast.LENGTH_LONG).show()
                            } else {
                                currentCode += it
                                etPrice.setText(currentCode)
                            }
                        } else {
                            CenterToasty.error(this,"金额最多设置2位小数！",Toast.LENGTH_LONG).show()
                        }
                    } else {
                        if (currentCode.startsWith("0") && currentCode.length == 1 && it == 0) {
                            CenterToasty.error(this,"第二位不能输入0！",Toast.LENGTH_LONG).show()
                        } else {
                            if (BigDecimal(currentCode + it).compareTo(BigDecimal("99999")) == 1) {
                                CenterToasty.error(this,"金额不能超过99999！",Toast.LENGTH_LONG).show()
                            } else {
                                currentCode += it
                                etPrice.setText(currentCode)
                            }
                        }
                    }
                }
            }
        }

        viewModel.payServiceResponseLiveData.observe(this,{ result ->
            loading.visibility = View.GONE

            result.getOrElse {
                it.message?.let { it1 -> CenterToasty.error(this, it1,Toast.LENGTH_LONG).show() }
                return@observe
            }

            result.getOrNull().also {
                it?.let { it1 ->
                    val intent = Intent()
                    intent.setClass(this@PriceInputActivity, PayCodeActivity::class.java)
                    intent.putExtra("payServiceResponse",it1)
                    startActivity(intent)
                }
            }
        })




    }
}