package com.miya.fastcashier.viewmodel

import android.text.TextUtils
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.blankj.utilcode.util.LogUtils
import com.blankj.utilcode.util.NumberUtils
import com.miya.fastcashier.beans.LoginRequest
import com.miya.fastcashier.beans.SelfCashierAccountInfo
import com.miya.fastcashier.repository.PayRepository
import com.miya.fastcashier.service.AccountService
import com.miya.fastcashier.service.LoginService
import com.miya.fastcashier.service.PrintService
import com.sdy.miya.moblie.component.pay.core.error.ParamInvalidException
import com.sdy.miya.moblie.component.pay.platform.bean.MiyaOrderRefundResponse
import com.sdy.miya.moblie.component.pay.platform.bean.PayServiceResponse
import kotlinx.coroutines.*
import java.util.*
import kotlin.collections.HashMap


class PayViewModel : ViewModel() {

    lateinit var payResultJob: Job

    val refundLiveData: MutableLiveData<Result<PayRepository>> = MutableLiveData()
    val payServiceResponseLiveData: MutableLiveData<Result<PayServiceResponse>> = MutableLiveData()
    val payResultLiveData: MutableLiveData<Result<PayServiceResponse>> = MutableLiveData()




    /**
     * oriOrderNo 原订单号
     * refundOrderNo 退款订单号
     * refundPrice 退款金额
     */
    fun refund(oriOrderNo: String, refundOrderNo: String, refundPrice: String) = runBlocking {

        val refundParams = HashMap<String, String>()
        refundParams["oriOrderNo"] = oriOrderNo;
        refundParams["refundOrderNo"] = refundOrderNo;
        refundParams["refundPrice"] = refundPrice;

        val refundResult = async(Dispatchers.IO) {
            PayRepository.refundByOrderNo(refundParams)
        }

        refundResult.await()

        val printResult = async(Dispatchers.IO) {
            AccountService.getAccountInfo()
                ?.let { PrintService.refundPrint(it, refundResult.await()) }
        }
        printResult.await()
//        refundLiveData.value = Result.success()
    }


    /**
     * payType 只支持微信或者支付宝
     * 2是微信 1是支付宝
     *
     * price 目前是元 转成分
     */
    fun generatePayCode(price: String,payType: String){
        if(TextUtils.isEmpty(price)){
            payServiceResponseLiveData.value = Result.failure(ParamInvalidException("请输入金额！"))
            return
        }
        //todo 检查小数字是否合法
        val orderNo = System.currentTimeMillis()

        viewModelScope.launch(Dispatchers.IO){
            try {
               val payServiceResponse =  PayRepository.generatePayCode(orderNo.toString(),"1","1")
                payServiceResponseLiveData.postValue(Result.success(payServiceResponse))
            }catch (e:Exception){
                payServiceResponseLiveData.postValue(Result.failure(e))
            }
        }
    }


    /**
     * 订单查询
     */
    fun payResultQuery(payServiceResponse: PayServiceResponse){
        payResultJob = viewModelScope.launch(Dispatchers.IO){
                while (isActive){
                    try {
                       LogUtils.e("订单查询！！")
                       val payServiceResponseResult =  PayRepository.payResultQuery(payServiceResponse.shopTradeNo)
                       payResultLiveData.postValue(Result.success(payServiceResponseResult))
                       break
                    }catch (e:Exception){
                        payResultLiveData.postValue(Result.failure(e))
                        Thread.sleep(3000)
                    }
                }
        }

    }



}